#!/bin/sh
dprint() {
  echo $1 > /dev/kmsg
}

r3str() {
  head /dev/urandom | tr -dc A-Za-z0-9 | head -c 3
}

evacuate() {
  cp iss.conf "isscr_$(r3str).conf"
  sync;sync;sync
}

. /lib/functions/crepo.sh
confts=""
check_config() {
  confn="/usr/local/bin/iss.conf"
  ts=$(date  +'%H%M%S' -r $confn)
  if [ "$ts" != "$confts" ]; then
    crepo_push_file $confn
    confts=$ts
  fi
}

led_bright() {
  sleep 10
  . /usr/bin/genenvs.sh
  if [ "$QSW_SLEDTYPE" == "DUAL" ]; then
    # enable green status LED without flashing
    /usr/bin/sys_stat.sh set_status_led green
    # turn on SFP_LED
    /usr/sbin/i2cset -y 0 0x4e 0x40 0x8
  fi
  SFP_LED_COUNT=1
}


snmp_alive() {
  snmpget -r1 -t 0.5 -c PUBLIC -v1 localhost  1.3.6.1.2.1.1.1.0 > /dev/null
}

cli_alive() {
  netstat -tnl | grep 6023 > /dev/null
}

iss_healthy() {
  cli_alive && snmp_alive
}

iss_ready() {
  cli_alive
}

check_backend() {
  [ -e /tmp/stopsign_backend ] && return
  iss_ready || return
  if ! pidof aricent-backend.arm; then
    logger  -p local1.4 -t issmon "Backend is gone! Relaunch it"
    ./aricent-backend.arm &
    sleep 1
  fi
}

injcmdf="/tmp/iss_inject.cmd"
check_inject_cmdf() {
    if [ -f $injcmdf ]; then
        dprint "got injfile $injcmdf"
        runisscmd.sh $injcmdf
        #dprint "$(echo 'show system info' | runisscmd.sh | grep 'Switch')"
        rm $injcmdf
    fi
}

launch_iss() {
    cd /usr/local/bin
    rm -f fsir.log*
    if [ -f iss.env ]; then
        . iss.env
        export $(cut -d= -f1 iss.env)
    fi
    ./ISS408wt.exe -daemon -config /etc/iss.config -redir_stdout /usr/var/iss.log
}

maxwait=50
stepsecs=2
notready_cnt=0
iss_notready_task() {
  notready_cnt=$(expr $notready_cnt + $stepsecs)
  ready_cnt=0
  [ $notready_cnt -gt $maxwait ] && dprint "ISS hasn't respond for a while! Reboot." && reboot
}

ready_cnt=0
iss_ready_task() {
    [ $ready_cnt -eq 0 ] && dprint "ISS gets ready"
    ready_cnt=$(expr $ready_cnt + $stepsecs)
    notready_cnt=0
    check_backend
    check_inject_cmdf
    check_config
}

SFP_LED_COUNT=0
VLAN_COUNT=0

launch_iss
while true; do
    sleep $stepsecs
    if ! pidof ISS408wt.exe >/dev/null ; then
        dprint "ISS process not found! We have to reboot!"
        reboot
    fi
    if [ $SFP_LED_COUNT == 0 ]; then
        if [ ! -f /etc/vlan.config -o $VLAN_COUNT == 1 ]; then
            iss_ready && led_bright
        fi
    fi
    if [ -f /etc/vlan.config ]; then
        if [ $VLAN_COUNT == 0 ]; then
            iss_ready && runisscmd.sh /etc/iss_vlan.txt && VLAN_COUNT=1
        fi
        continue
    fi
    if iss_healthy ; then
        iss_ready_task
    else
        iss_notready_task
    fi
done
